@@ -1,10 +1,10 @@
-# Copyrights 2012-2014 by [Mark Overmeer].
+# Copyrights 2012-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 package Apache::Solr::Document;
 use vars '$VERSION';
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 
 use warnings;
@@ -77,7 +77,10 @@ sub field($)
 }
 
 
-sub content($) { my $f = $_[0]->field($_[1]); $f ? $f->{content} : undef }
+sub content($)
+{   my $f = $_[0]->field($_[1]);
+    $f ? $f->{content} : undef;
+}
 
 our $AUTOLOAD;
 sub AUTOLOAD
