@@ -1,10 +1,10 @@
-# Copyrights 2012-2014 by [Mark Overmeer].
+# Copyrights 2012-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 package Apache::Solr::XML;
 use vars '$VERSION';
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 use base 'Apache::Solr';
 
@@ -105,8 +105,14 @@ sub _doc2xml($$$)
     foreach my $field ($this->fields)
     {   my $fnode = $doc->createElement('field');
         $fnode->setAttribute(name => $field->{name});
+
         my $boost = $field->{boost} || 1.0;
-        $fnode->setAttribute(boost => $boost) if $boost != 1.0;
+        $fnode->setAttribute(boost => $boost)
+            if $boost < 0.9999 || $boost > 1.0001;
+
+        $fnode->setAttribute(update => $field->{update})
+            if defined $field->{update};
+
         $fnode->appendText($field->{content});
         $node->addChild($fnode);
     }
